% RAMSEY.M
% Find time paths for the Ramsey model using the backward integration method
% Reference: Brunner,M. and H. Strulik (1998,2001):
% Solution of Perfect Foresight Saddlepoint Problems:
% A Simple Method and Applications
% uses ramsdot.m and ode45ext.m

% c = consumption
% k = capital
% ks, cs = steady state 

echo off; clear all;
global theta rho delta a 
%endtime 
% *********************** Initialize Parameters ***********************
delta = .05;       		% depreciation rate of k
rho = .02;           	% rate of time preference
a = .3;            		% capital share 
% Special case of theta that ensures a constant savings rate
theta = (delta+rho)./(a.*delta); 
%theta=2;

s=a*delta/(delta+rho);

% ******************* steady state ************************************
ks = (a/(rho+delta))^(1/(1-a));
cs = (ks^a - delta*ks);

% ******************* Initial Step ************************************
% Eigenvalue
eig1=1;
B=(a.*s).*(a-1).*cs.*ks.^(a-2);
eig2=(rho+sqrt(rho^2-4*B))./2;

% Arbitrary Values
%eig2=100;

% Step Direction
uniteig=1/norm([eig1,eig2])*[eig1;eig2];

% Step Length
mu=10^(-5);

%********** Initial Value and Direction of Integration ****************
for dir=0:1
if dir==0 kfinal=0.1*ks; end
if dir==1 kfinal=2*ks; end
xstart=[ks;cs]-mu*uniteig*(-1)^dir;	

% ******************* Backward Integration ****************************
[t,x] = ode45mod('ramsdot2',xstart,kfinal,1,10^(-7),0);

%**************** Reverse to forward looking **************************
% Reverse Time
t=max(t)-t;

% Reverse Solution Vector 
t=t(length(t):-1:1);
x=x(length(t):-1:1,:);

% Extract k an c
k=x(:,1); c=x(:,2);
krel=k./ks; crel=c./cs;

% ***************************** Plot the Results **********************
subplot(2,2,1)
plot(t,krel,'b-')
hold on
axis([0 max(t) 0 2])
xlabel('time')
ylabel('k/k^*')

subplot(2,2,2)
plot(t,crel,'b-')
hold on
axis([0 max(t) 0 max(c)])
xlabel('time')
ylabel('c/c^*')

subplot(2,2,3)
plot(krel,crel,'b-',ks,cs,'b*')
hold on
axis([0 2 0 max(c)])
xlabel('k/k^*')
ylabel('c/c^*')

end

